#!/bin/bash

# Copy data from one certreq database to another

set -e

# First, create a file like this:
#
# SOURCE_HOST=mysql-app.stanford.edu
# SOURCE_DB=s_certreq_prod
# SOURCE_USER=s_certreq_prod
# SOURCE_PW=secret
# DEST_HOST=mysql-app.stanford.edu
# DEST_DB=s_certreq_dev
# DEST_USER=s_certreq_dev
# DEST_PW=secret

# Then run this script with a single argument of the name of the above
# created file.

if [[ "$1" == "" ]]; then
    echo "error: missing database configuration file name"
    exit 1
fi

source $1

# It is VERY important we don't overwrite production.
if [[ "$DEST_DB" =~ prod ]]; then
    print "You are trying to overwrite production? NO!!!"
    exit 1
fi

SOURCE_SQL=/tmp/source.sql

# Dump source
rm -f $SOURCE_SQL
echo "dumping database '$SOURCE_DB'..."
mysqldump -u $SOURCE_USER -p$SOURCE_PW -h $SOURCE_HOST $SOURCE_DB > /tmp/source.sql

# Remove "DEFINER=..." lines; see also
# https://stackoverflow.com/questions/44015692/access-denied-you-need-at-least-one-of-the-super-privileges-for-this-operat
sed 's/\sDEFINER=`[^`]*`@`[^`]*`//g' -i /tmp/source.sql

# Load into destination
echo "loading into destination database '$DEST_DB'..."
mysql -u $DEST_USER -p$DEST_PW -h $DEST_HOST $DEST_DB < /tmp/source.sql

# Clean up
echo "cleaning up..."
rm -f $SOURCE_SQL

echo "be sure to remove $1 (it has passwords!!)"
