package Stanford::Certificate::Result::AllContacts;

# A view that returns all contact e-mail addresses that are associated
# with at least one valid (non-revoked, nonn-expired) certificate.

use strict;
use warnings;
use base qw/DBIx::Class::Core/;

__PACKAGE__->table_class('DBIx::Class::ResultSource::View');

# For the time being this is necessary even for virtual views
__PACKAGE__->table('AllContacts');

#
# ->add_columns, etc.
#

# do not attempt to deploy() this view
__PACKAGE__->result_source_instance->is_virtual(1);

__PACKAGE__->result_source_instance->view_definition(q[
SELECT
DISTINCT certificates.contact_email AS contact_email
FROM certificates
WHERE ((certificates.expires_at > now()) AND
       (not(certificates.id in
         (
           SELECT
           incommon_statuses.certificate_id
           FROM incommon_statuses
           WHERE (incommon_statuses.status = 'revoked'))
         )
       ))
]);

__PACKAGE__->add_columns(
    'contact_email' => {
        data_type => 'varchar',
        size      => 180,
    },
);

1;
