##############################################################################
# NetDB Info class
##############################################################################
package Stanford::NetDBInfo ;

## no critic (Subroutines::RequireArgUnpacking) ;

use strict;
use warnings;

use Readonly ;

Readonly my $RESULT_NO_NODE         =>  4 ;
Readonly my $RESULT_NO_DOMAIN       =>  8 ;
Readonly my $RESULT_CONTROLS_NODE   => 16 ;
Readonly my $RESULT_CONTROLS_DOMAIN => 32 ;

sub new {
    my ($proto, %args) = @_ ;
    my $self = {} ;
    my $class = ref($proto) || $proto ;

    $self->{'results'} = $args{'results'} || undef ;

    $self->{'controls_node'}   = {} ;
    $self->{'controls_domain'} = {} ;

    bless($self, $class) ;

    $self->initialize() ;

    return $self ;
}

# Returns 1 if a NODE object with the name $node_name exists in NetDB,
# 0 otherwise.
sub node_exists {
    my $self = shift ;
    my ($node_name) = @_ ;

    if (exists($self->{'controls_node'}->{$node_name})) {
        return 1 ;
    } else {
        return 0 ;
    }
}

# Returns 1 if a DOMAIN object with the name $node_name exists in NetDB,
# 0 otherwise.
sub domain_exists {
    my $self = shift ;
    my ($domain_name) = @_ ;

    if (exists($self->{'controls_domain'}->{$domain_name})) {
        return 1 ;
    } else {
        return 0 ;
    }
}

# $control should be 0 for does NOT control, 1 for DOES control
sub controls_node {
    my $self = shift ;
    my ($node_name, $control) = @_ ;

    if (defined($control)) {
        $self->{'controls_node'}->{$node_name} = $control ;
    }

    return $self->{'controls_node'}->{$node_name} ;
}

# $control should be 0 for does NOT control, 1 for DOES control
sub controls_domain {
    my $self = shift ;
    my ($domain_name, $control) = @_ ;

    if (defined($control)) {
        $self->{'controls_domain'}->{$domain_name} = $control ;
    }

    return $self->{'controls_domain'}->{$domain_name} ;
}

# Take results in $self->{'results'} and parse.
sub initialize {
    my $self = shift ;

    my $results = $self->{'results'} ;

    my $fs = q{:} ;

    my @results = split(/$fs/xsm, $results) ;

    foreach my $result (@results) {
        my ($user, $host, $result_code) = split(/,/xsm, $result) ;

        if ($result_code & $RESULT_NO_NODE) {
            ## NO_NODE_IN_NETDB
            ## We do nothing.
        } elsif ($result_code & $RESULT_CONTROLS_NODE) {
            ## USER_CONTROLS_NODE
            $self->controls_node($host, 1) ;
        } else {
            ## USER_DOES_NOT_CONTROL_NODE
            $self->controls_node($host, 0) ;
        }

        if ($result_code & $RESULT_NO_DOMAIN) {
            ## NO_DOMAIN_IN_NETDB
        } elsif ($result_code & $RESULT_CONTROLS_DOMAIN) {
            ## USER_CONTROLS_DOMAIN
            $self->controls_domain($host, 1) ;
        } else {
            ## USER_DOES_NOT_CONTROL_NODE
            $self->controls_domain($host, 0) ;
        }

    }

    return $self ;
}

1;
